@@ -21,4 +21,5 @@ from .hydra import hydra_route
 from .hydra import UMF_Message
 
 def version():
-    return '0.1.1'
+    version = open('VERSION').read()
+    return version
